musa: fix build warnings (#15611)

Signed-off-by: Xiaodong Ye <xiaodong.ye@mthreads.com>
This commit is contained in:
R0CKSTAR
2025-09-26 02:56:10 +02:00
committed by GitHub
parent 835b2b915c
commit 0f7c69689f
4 changed files with 6 additions and 4 deletions
+2 -2
View File
@@ -81,7 +81,7 @@ static __global__ void mmq_ids_helper(
#pragma unroll
for (int offset = neu_padded; offset < warp_size; offset += neu_padded) {
const int tmp = __shfl_up_sync(0xFFFFFFFF, it_compact_add_self, offset, warp_size);
if (threadIdx.x >= offset) {
if (threadIdx.x >= static_cast<unsigned int>(offset)) {
it_compact_add_lower += tmp;
}
}
@@ -110,7 +110,7 @@ static __global__ void mmq_ids_helper(
expert_bounds[expert] = nex_prev;
if (expert < gridDim.x - 1) {
if (expert < static_cast<int>(gridDim.x) - 1) {
return;
}